"""camp URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/1.11/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  url(r'^$', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  url(r'^$', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.conf.urls import url, include
    2. Add a URL to urlpatterns:  url(r'^blog/', include('blog.urls'))
"""
from django.conf import settings
from django.urls import include, re_path

from django.conf.urls.static import static
from django.contrib import admin
from django.views.generic import RedirectView

from markdownx import urls as markdownx
from photologue.views import GalleryListView

from content import views



urlpatterns = [
    re_path(r'^admin/', admin.site.urls),
    re_path(r'^$', views.index, name='index'),

    re_path(r'^.*index.php$', views.redirect_index, name='redirect_index'),
    re_path(r'^.*event.php$', views.redirect_event, name='redirect_event'),
    re_path(r'^.*(/images/.*)$', views.redirect_images, name='redirect_images'),
    re_path(r'directions.html', RedirectView.as_view(url='/directions/')),
    re_path(r'campstudio.html', RedirectView.as_view(url='/directions/')),

    re_path(r'^contact/$', views.contact),

    re_path(r'^texts/index/$', views.section_list, {'section': 'Texts'}, name='texts_list'),
    re_path(r'^events/index/$', views.section_list, {'section': 'Events'}, name='events_list'),
    re_path(r'^projects/index/$', views.section_list, {'section': 'Projects'}, name='projects_list'),
    re_path(r'^works/index/$', views.section_list, {'section': 'Works'}, name='works_list'),

    re_path(r'^texts/(?P<shortname>.+)/$', views.texts, name='text'),
    re_path(r'^events/(?P<shortname>.+)/$', views.events, name='event'),
    re_path(r'^projects/(?P<shortname>.+)/$', views.projects, name='project'),
    re_path(r'^works/(?P<shortname>.+)/$', views.works, name='work'),
    re_path(r'^works/$', views.works, name='works'),
    re_path(r'^projects/$', views.projects, name='projects'),
    re_path(r'^events/$', views.events, name='events'),
    re_path(r'^texts/$', views.texts, name='texts'),
    re_path(r'^search/$', views.search, name='search'),
    re_path(r'^markdownx/', include(markdownx)),
    re_path(r'^photologue/', include('photologue.urls', namespace='photologue')),
    re_path(r'^gallerylist/$', GalleryListView.as_view(), name='gallery-list'),
]

if settings.DEBUG:
    urlpatterns += static(settings.STATIC_URL, document_root=settings.STATIC_ROOT)

urlpatterns += [
    re_path(r'^(?P<shortname>\w+)/$', views.page, name='page')
]

